@@ -26,18 +26,19 @@ class Options(argparse.ArgumentParser):
 
             For a local run, use :
 
-                sequana_pipelines_demultiplex --input-directory PATH_TO_DATA --run-mode local
+                sequana_pipelines_demultiplex --bcl-directory PATH_TO_DATA --samplesheet SampleSheet.csv
 
-            For a run on a SLURM cluster:
-
-                sequana_pipelines_demultiplex --input-directory PATH_TO_DATA --run-mode slurm
 
         """
         )
-        super(Options, self).__init__(usage=usage, prog=prog, description="")
+        super(Options, self).__init__(usage=usage, prog=prog, description="",
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter
+        )
 
         # add a new group of options to the parser
-        so = SlurmOptions()
+        # demultiplex requires lots of memory sometimes hence the 64G options
+        # 
+        so = SlurmOptions(queue="biomics", memory="64000", cores=16)
         so.add_options(self)
 
         # add a snakemake group of options to the parser
@@ -51,14 +52,14 @@ class Options(argparse.ArgumentParser):
 
         pipeline_group = self.add_argument_group("pipeline")
 
-        pipeline_group.add_argument("--threads", dest="threads", default=4, type=int)
+        pipeline_group.add_argument("--threads", dest="threads", default=4,
+            type=int, help="Number of threads to use during the demultiplexing")
         pipeline_group.add_argument("--barcode-mismatch", dest="mismatch", default=0, type=int)
-        pipeline_group.add_argument("--merge", dest="merge", action="store_true")
+        pipeline_group.add_argument("--merging-strategy", required=True,
+            dest="merging_strategy", choices=["merge", "none"], 
+            help="""Merge Lanes of not. Set to 'merge' to merge all lanes. Set
+            to 'none' to NOT merge the lanes""")
         pipeline_group.add_argument("--bcl-directory", dest="bcl_directory")
-        pipeline_group.add_argument("--output-directory",
-            dest="output_directory", default="fastq",
-            help="Where to save the FASTQ results (default fastq )",
-        )
         pipeline_group.add_argument("--samplesheet", dest="samplesheet", 
             default="SampleSheet.csv")
         pipeline_group.add_argument("--ignore-missing-controls", 
@@ -67,8 +68,6 @@ class Options(argparse.ArgumentParser):
             dest="ignore_missing_bcls", action="store_true", default=True)
         pipeline_group.add_argument("--no-bgzf-compression",
             dest="no_bgzf_compression", action="store_true", default=True)
-        pipeline_group.add_argument("--merge_all_lanes",
-            dest="merge_all_lanes", action="store_true", default=True)
         pipeline_group.add_argument("--write-fastq-reverse-complement",
             dest="write_fastq_reverse_complement", action="store_true", default=True)
 
@@ -80,6 +79,7 @@ def main(args=None):
 
     if "--version" in sys.argv:
         print_version(NAME)
+        sys.exit(0)
 
     options = Options(NAME).parse_args(args[1:])
 
@@ -92,7 +92,6 @@ def main(args=None):
     if os.path.exists(options.samplesheet) is False:
         raise IOError("Please provide an existing sample sheet file with --samplesheet")
 
-
     cfg = manager.config.config
     cfg.input_directory = os.path.abspath(options.bcl_directory)
     cfg.bcl2fastq.threads = options.threads
@@ -103,11 +102,15 @@ def main(args=None):
         logger.error("Input Samplesheet {} not found. ".format(options.samplesheet))
         sys.exit(1)
 
-    cfg.bcl2fastq.output_directory = options.output_directory
+    # this is defined by the working_directory
+    cfg.bcl2fastq.output_directory = "."
     cfg.bcl2fastq.ignore_missing_controls= options.ignore_missing_controls
     cfg.bcl2fastq.ignore_missing_bcls = options.ignore_missing_bcls
     cfg.bcl2fastq.no_bgzf_compression = options.no_bgzf_compression
-    cfg.bcl2fastq.merge_all_lanes = options.merge_all_lanes
+    if options.merging_strategy == "merge":
+        cfg.bcl2fastq.merge_all_lanes = True
+    elif options.merging_strategy == "none":
+        cfg.bcl2fastq.merge_all_lanes = False
     cfg.bcl2fastq.write_fastq_reverse_complement = options.write_fastq_reverse_complement
 
     # finalise the command and save it; copy the snakemake. update the config
